ring.hot-reload.client

Generates client-side JavaScript for hot reload.

Generates client-side JavaScript for hot reload.
raw docstring

ring.hot-reload.core

Ring middleware for hot reload of server-rendered applications.

Ring middleware for hot reload of server-rendered applications.
raw docstring

ring.hot-reload.inject

HTML response detection and script injection.

HTML response detection and script injection.
raw docstring

ring.hot-reload.nrepl

Optional nREPL middleware that triggers hot reload on eval completion.

Add to .nrepl.edn: {:middleware [ring.hot-reload.nrepl/wrap-hot-reload-nrepl]}

Optional nREPL middleware that triggers hot reload on eval completion.

Add to .nrepl.edn:
  {:middleware [ring.hot-reload.nrepl/wrap-hot-reload-nrepl]}
raw docstring

ring.hot-reload.watcher

File watcher abstraction with a default beholder implementation.

File watcher abstraction with a default beholder implementation.
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries