ring.hot-reload.nrepl

Optional nREPL middleware that triggers hot reload on eval completion.

Add to .nrepl.edn: {:middleware [ring.hot-reload.nrepl/wrap-hot-reload-nrepl]}

Optional nREPL middleware that triggers hot reload on eval completion.

Add to .nrepl.edn:
  {:middleware [ring.hot-reload.nrepl/wrap-hot-reload-nrepl]}
raw docstring

wrap-hot-reload-nreplclj

(wrap-hot-reload-nrepl handler)

nREPL middleware that triggers a hot reload when an eval operation completes. Uses the global notification mechanism in ring.hot-reload.core.

nREPL middleware that triggers a hot reload when an eval operation completes.
Uses the global notification mechanism in ring.hot-reload.core.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries