ring.hot-reload.watcher

File watcher abstraction with a default beholder implementation.

File watcher abstraction with a default beholder implementation.
raw docstring

beholder-watcherclj

(beholder-watcher paths extensions)

Creates a Watcher backed by nextjournal/beholder.

paths - collection of directory paths to watch extensions - collection of file extension strings (e.g. [".clj" ".cljc"])

Creates a Watcher backed by nextjournal/beholder.

`paths`      - collection of directory paths to watch
`extensions` - collection of file extension strings (e.g. [".clj" ".cljc"])
sourceraw docstring

debounceclj

(debounce f delay-ms)

Returns a debounced function that collects arguments during a delay window. f is called with the set of all values passed to :invoke during the window. Returns a map with :invoke (fn [value]) and :shutdown (to clean up).

Returns a debounced function that collects arguments during a delay window.
`f` is called with the set of all values passed to :invoke during the window.
Returns a map with :invoke (fn [value]) and :shutdown (to clean up).
sourceraw docstring

Watchercljprotocol

start!clj

(start! this callback)

Start watching. Calls (callback) on file changes. Returns a value that can be passed to stop! to terminate watching.

Start watching. Calls (callback) on file changes. Returns a value
that can be passed to stop! to terminate watching.

stop!clj

(stop! this handle)

Stop watching. handle is the value returned by start!.

Stop watching. `handle` is the value returned by start!.
source

cljdoc builds & hosts documentation for Clojure/Script libraries