Optional nREPL middleware that triggers hot reload on eval completion.
Add to .nrepl.edn: {:middleware [ring.hot-reload.nrepl/wrap-hot-reload-nrepl]}
Optional nREPL middleware that triggers hot reload on eval completion.
Add to .nrepl.edn:
{:middleware [ring.hot-reload.nrepl/wrap-hot-reload-nrepl]}(wrap-hot-reload-nrepl handler)nREPL middleware that triggers a hot reload when an eval operation completes. Uses the global notification mechanism in ring.hot-reload.core.
nREPL middleware that triggers a hot reload when an eval operation completes. Uses the global notification mechanism in ring.hot-reload.core.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |